;;;
;;; My key bindings, inspired by Brief on my '386 box.
;;;

;; Function key mapping is to start with \C-^ as the first character.
;; This seems to not be used in the standard key maps.

;;; Function keys!
;; Praise the Lord and pass the ammunition!
;; This stuff here prevents the function keys from screwing up during search
;; and other minibuffer activities, as it does when for the default settings,
;; which have ESC as the first char.
;;
;; Shift Lock    1
;; Left Shift    2      Right Shift    4
;; Left Meta     8      Right Meta     16
;; Left Control  32     Right Control  64
;; Left Alt      128    Right Alt      256
;; 
(setq with-shift (epoch::mod-to-shiftmask 0))
(setq with-control (epoch::mod-to-shiftmask 2))
(setq with-meta (epoch::mod-to-shiftmask 3))
(setq with-alt (epoch::mod-to-shiftmask 4))

;; Conventions: All rebound keys send control-^ first, followed by their
;; key value, lower for 1-9, uppercase for 10-19. Before the keycode, the
;; letter C is added for control keys, S for shifted keys, A for alt
;; M for Meta. An underscore indicates a normal key (e.g., Alt-l is
;; \C-^A_l (A for Alt, _ for letter, l for the keysym))

;; Warning - This rebinding depends on using xmodmap to switch keysyms.
;; Warning - What happens normally is that shift states cause the base
;; Warning - keysym to change. The modmap that I use forces the base keysyms
;; Warning - to be stable regardless of the shift state. The modmap is included
;; Warning - at the end of this file.
;;
;; special keys

(setq epoch::function-key-mapping nil)	;turn off ESC mapping for function keys

(epoch::rebind-key "Help" 0 "\C-h")
(epoch::rebind-key "R6" 0 "\C-^r6")

; Home
(rebind-key "Home" 0 "\C-^r7")
(rebind-key "R7" 0 "\C-^r7")
(rebind-key "Home" with-control "\C-^Cr7")
(rebind-key "R7" with-control "\C-^Cr7")
(rebind-key "R7" with-shift "\C-^Sr7")

(rebind-key "Up" 0 "\C-^r8")
(rebind-key "R8" with-shift "\C-^Sr8")
(rebind-key "Up" with-shift "\C-^Sr8")
(rebind-key "Up" with-control "\C-^Cr8")
(rebind-key "Up" with-meta "\C-^Mr8")

; Page Up
(rebind-key "Prior" 0 "\C-^r9")
(rebind-key "R9" 0 "\C-^r9")
(rebind-key "R9" with-shift "\C-^Sr9")
(rebind-key "Prior" with-control "\C-^Cr9")
(rebind-key "Prior" with-meta "\C-^Mr9")
(rebind-key "R9" with-control "\C-^Cr9")
(rebind-key "R9" with-meta "\C-^Mr9")

(rebind-key "Left" 0 "\C-^R0")
(rebind-key "Left" with-control "\C-^CR0")
(rebind-key "R10" with-shift "\C-^SR0")
(rebind-key "Left" with-shift "\C-^SR0")
(rebind-key "Left" with-meta "\C-^MR0")

; center
(rebind-key "R11" 0 "\C-^R1")
(rebind-key "R11" with-shift "\C-^SR1")
(rebind-key "R11" with-control "\C-^CR1")

(rebind-key "Right" 0 "\C-^R2")
(rebind-key "Right" with-control "\C-^CR2")
(rebind-key "R12" with-shift "\C-^SR2")
(rebind-key "Right" with-shift "\C-^SR2")
(rebind-key "Right" with-meta "\C-^MR2")

; end
(rebind-key "End" 0 "\C-^R3")
(rebind-key "R13" 0 "\C-^R3")
(rebind-key "R13" with-shift "\C-^SR3")
(rebind-key "End" with-control "\C-^CR3")
(rebind-key "R13" with-control "\C-^CR3")

(rebind-key "Down" 0 "\C-^R4")
(rebind-key "R14" with-shift "\C-^SR4")
(rebind-key "Down" with-shift "\C-^SR4")
(rebind-key "Down" with-control "\C-^CR4")

; Page Down
(rebind-key "Next" 0 "\C-^R5")
(rebind-key "R15" 0 "\C-^R5")
(rebind-key "R15" with-shift "\C-^SR5")
(rebind-key "Next" with-control "\C-^CR5")
(rebind-key "Next" with-meta "\C-^MR5")
(rebind-key "R15" with-control "\C-^CR5")
(rebind-key "R15" with-meta "\C-^MR5")

(rebind-key "equal" with-control "\C-^C=")
(rebind-key "equal" with-alt "\C-^A=")
(rebind-key "minus" with-control "\C-^C-")
(rebind-key "minus" with-alt "\C-^A-")

;

(global-set-key "\C-^r6" 'undo)		; keypad * on new suns

;; Normal cursor keys move characters and lines
(global-set-key "\C-^r8" 'previous-line)
(global-set-key "\C-^R4" 'next-line)
(global-set-key "\C-^R0" 'backward-char)
(global-set-key "\C-^R2" 'forward-char)

;; Shifted horizontal goes words
(global-set-key "\C-^SR2" 'forward-word)
(global-set-key "\C-^SR0" 'backward-word)
(global-set-key "\C-^Sr8" 'scroll-down-one)
(global-set-key "\C-^SR4" 'scroll-up-one)
;; shifted page switches screens
(global-set-key "\C-^Sr9" (definteractive (select-screen (next-screen))))
					;shift page-up
(global-set-key "\C-^SR5" (definteractive (select-screen (prev-screen))))
					;shift page-down

(global-set-key "\C-^r7" 'beginning-of-line) ;Home
(global-set-key "\C-^R1" 'recenter)	;Center
(global-set-key "\C-^R3" 'end-of-line)	;End
(global-set-key "\C-^Cr7" 'beginning-of-buffer)	;control Home
(global-set-key "\C-^CR3" 'end-of-buffer) ;control End
(global-set-key "\C-^SR1" 'exchange-point-and-mark) ;shift center

(global-set-key "\C-^Cr9" (definteractive (raise-screen))) ;control page-up
(global-set-key "\C-^CR5" (definteractive (lower-screen))) ;control page-down

(global-set-key "\C-^C=" 'split-window-vertically) ;control =
(global-set-key "\C-^C-" 'delete-other-windows)	;control -

(global-set-key "\C-^r9" 'page-up)	;page-up
(global-set-key "\C-^R5" 'page-down)	;page-down

